@@ -6,6 +6,8 @@ import warnings
 from datetime import datetime
 from typing import Tuple, Mapping, Any, Callable, Union, Iterable, Type
 
+import pytz
+
 from .serializers.base import BaseTaskSerializer
 from .serializers.betterproto import BetterprotoSerializer
 from .task import Task, TaskMetadata, TaskDecodeError
@@ -73,7 +75,7 @@ class PatchworkPublisher(Component):
         """
         if not task.uuid:
             task.uuid = str(uuid.uuid4())
-        task.meta.scheduled = datetime.now()
+        task.meta.scheduled = datetime.now(pytz.UTC)
 
         if task.meta.expires and task.meta.expires < task.meta.scheduled:
             raise ValueError('unable to send task which is already expired')
@@ -166,7 +168,7 @@ class PatchworkSubscriber(Component):
             handled = self._handle_deserialize_error(payload, meta, exc)
             raise TaskDecodeError(payload, meta, exc, handled) from exc
 
-        task.meta.received = datetime.now()
+        task.meta.received = datetime.now(pytz.UTC)
         task.meta.queue_name = meta.get('queue_name', None)
         return task
 
