@@ -3,6 +3,7 @@ import sys
 from importlib import import_module
 
 from pydantic import ValidationError
+from pydantic.error_wrappers import ErrorWrapper
 from pydantic.fields import ModelField
 from typing import Union, Text, Any, TypeVar, Generic, Type
 
@@ -45,7 +46,13 @@ class ClassPath(Generic[T]):
                              f"module and class name joined by colon, eg: foo.bar:MyClass")
 
         mod_name, class_name = v.split(':')
-        mod = import_module(mod_name)
+        try:
+            mod = import_module(mod_name)
+        except Exception as e:
+            exc = ImportError(f'unable to import {mod_name}: {e.__class__.__name__}({e})')
+            raise ValidationError([
+                ErrorWrapper(exc=exc, loc='cls')
+            ], cls)
 
         for module_name, module in sys.modules.items():
             # skip empty modules and ones without actual file
